==> zio-aws-networkmanager_2.13-6.20.162.1-sources.jar: zio/aws/networkmanager/model/VpcOptions.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class VpcOptions(
    ipv6Support: Optional[Boolean] = Optional.Absent,
    applianceModeSupport: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.VpcOptions = {
    import VpcOptions.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.VpcOptions
      .builder()
      .optionallyWith(ipv6Support.map(value => value: java.lang.Boolean))(
        _.ipv6Support
      )
      .optionallyWith(
        applianceModeSupport.map(value => value: java.lang.Boolean)
      )(_.applianceModeSupport)
      .build()
  }
  def asReadOnly: zio.aws.networkmanager.model.VpcOptions.ReadOnly =
    zio.aws.networkmanager.model.VpcOptions.wrap(buildAwsValue())
}
object VpcOptions {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.VpcOptions
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.networkmanager.model.VpcOptions =
      zio.aws.networkmanager.model.VpcOptions(
        ipv6Support.map(value => value),
        applianceModeSupport.map(value => value)
      )
    def ipv6Support: Optional[Boolean]
    def applianceModeSupport: Optional[Boolean]
    def getIpv6Support: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("ipv6Support", ipv6Support)
    def getApplianceModeSupport: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("applianceModeSupport", applianceModeSupport)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.VpcOptions
  ) extends zio.aws.networkmanager.model.VpcOptions.ReadOnly {
    override val ipv6Support: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.ipv6Support())
      .map(value => value: Boolean)
    override val applianceModeSupport: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.applianceModeSupport())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.VpcOptions
  ): zio.aws.networkmanager.model.VpcOptions.ReadOnly = new Wrapper(impl)
}

==> zio-aws-networkmanager_3-5.17.103.1-sources.jar: zio/aws/networkmanager/model/VpcOptions.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class VpcOptions(ipv6Support: Option[Boolean] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.VpcOptions = {
    import VpcOptions.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.VpcOptions
      .builder()
      .optionallyWith(ipv6Support.map(value => value: java.lang.Boolean))(
        _.ipv6Support
      )
      .build()
  }
  def asReadOnly: zio.aws.networkmanager.model.VpcOptions.ReadOnly =
    zio.aws.networkmanager.model.VpcOptions.wrap(buildAwsValue())
}
object VpcOptions {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.VpcOptions
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.networkmanager.model.VpcOptions =
      zio.aws.networkmanager.model.VpcOptions(ipv6Support.map(value => value))
    def ipv6Support: Option[Boolean]
    def getIpv6Support: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("ipv6Support", ipv6Support)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.VpcOptions
  ) extends zio.aws.networkmanager.model.VpcOptions.ReadOnly {
    override val ipv6Support: Option[Boolean] =
      scala.Option(impl.ipv6Support()).map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.VpcOptions
  ): zio.aws.networkmanager.model.VpcOptions.ReadOnly = new Wrapper(impl)
}
